BeResponsivePoints class final

Mixed-in types

Constructors

BeResponsivePoints({double sm = 640, double md = 768, double lg = 1024, double xl = 1280, double xl2 = 1536})
Creates a BeResponsivePoints.
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
lg → double
The minimum width of the large breakpoint, inclusive. Defaults to 1024.
final
md → double
The minimum width of the medium breakpoint, inclusive. Defaults to 768.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sm → double
The minimum width of the small breakpoint, inclusive. Defaults to 640.
final
xl → double
The minimum width of the extra large breakpoint, inclusive. Defaults to 1280.
final
xl2 → double
The minimum width of the extra extra large breakpoint, inclusive. Defaults to 1536.
final

Methods

debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
valueForBreakpoint(BeBreakpoint breakpoint) → double
Returns the numeric value for a given BeBreakpoint enum.

Operators

operator ==(Object other) → bool
The equality operator.
override